@@ -7,13 +7,12 @@ Release logic:
  3. git add filer/__init__.py CHANGELOG.rst
  4. git commit -m 'Bump to {new version}'
  5. git push
- 6. Assure that all tests pass on https://travis-ci.org/github/divio/django-filer.
- 7. git tag {new version}
- 8. git push --tags
- 9. python setup.py sdist
-10. twine upload dist/django-filer-{new version}.tar.gz
+ 6. Assure that all tests pass on https://github.com/django-cms/django-filer/actions
+ 7. Create a new release on github. Create the new tag against the latest master commit and auto generate
+    the release notes https://github.com/django-cms/django-filer/releases/new
+ 8. Publish the release and it will automatically release to pypi
 """
 
-__version__ = '2.1.2'
+__version__ = '2.2.1'
 
 default_app_config = 'filer.apps.FilerConfig'
