@@ -6,11 +6,30 @@ class ThumbnailOption(models.Model):
     """
     This class defines the option use to create the thumbnail.
     """
-    name = models.CharField(_("name"), max_length=100)
-    width = models.IntegerField(_("width"), help_text=_('width in pixel.'))
-    height = models.IntegerField(_("height"), help_text=_('height in pixel.'))
-    crop = models.BooleanField(_("crop"), default=True)
-    upscale = models.BooleanField(_("upscale"), default=True)
+    name = models.CharField(
+        _("name"),
+        max_length=100,
+    )
+
+    width = models.IntegerField(
+        _("width"),
+        help_text=_("width in pixel."),
+    )
+
+    height = models.IntegerField(
+        _("height"),
+        help_text=_("height in pixel."),
+    )
+
+    crop = models.BooleanField(
+        _("crop"),
+        default=True,
+    )
+
+    upscale = models.BooleanField(
+        _("upscale"),
+        default=True,
+    )
 
     class Meta:
         app_label = 'filer'
@@ -33,5 +52,10 @@ class ThumbnailOption(models.Model):
             thumbnailer = filerimage.easy_thumbnails_thumbnailer
             thumb_image = thumbnailer.get_thumbnail(option_dict)
         """
-        return {"size": (self.width, self.height), "width": self.width,
-                "height": self.height, "crop": self.crop, "upscale": self.upscale}
+        return {
+            'size': (self.width, self.height),
+            'width': self.width,
+            'height': self.height,
+            'crop': self.crop,
+            'upscale': self.upscale,
+        }
